.g-widget-readme-header
  background-color #f0f0f0
  padding 5px 6px
  color #555
  font-size 16px
  font-weight bold

  i
    font-style normal

.g-widget-readme-content
  margin 3px
  margin-top 5px
  border-bottom 1px solid #f0f0f0
  min-height 25px
  font-size 14px
  color #777
